#!/bin/bash
DESC="initialization of working counter for Quality Assurance"

PATH=/sbin:/bin:/usr/sbin:/usr/bin

PROPCLI="/usr/sbin/propcli"
SYNCH_FILE="/config/last_synch"
UPTIME_FILE="/config/uptime"

source maxwell-log-functions.sh

if [ ! -x ${PROPCLI} ]; then
    echo "${PROPCLI} binary is missing!"
    exit 1
fi

wait_ipc()
{
    log_info "Checking if property service is ready..."
    /usr/sbin/propcli get System.QA.Startups --wait-timeout $1 1>/dev/null
    EXIT_CODE=$?
    if [ ${EXIT_CODE} != "0" ]; then
        log_error "Property Service not responding after $1 seconds."
        exit 1
    fi
}

do_onStart()
{
    wait_ipc 10
    TMP=$(${PROPCLI} get System.QA.Startups)
    TMP=$((TMP+1))
    ${PROPCLI} set System.QA.Startups $TMP

	if [ ! -f $SYNCH_FILE ]; then
		echo 0 > $SYNCH_FILE
	fi

	COUNTER_IN_HOURS=`${PROPCLI} get System.QA.WorkingCounter`
	STORED_UPTIME=`${PROPCLI} get System.QA.WorkingCounterSec`
	LAST_SYNCH=$(cat $SYNCH_FILE)

	# Update working counter in seconds from old counter in hours if needed
	# Working counter in seconds will be 0 only after first sw update
	if [ $STORED_UPTIME -eq 0 ]; then
		STORED_UPTIME=$((COUNTER_IN_HOURS*3600))
		log_info "Set working timer to $STORED_UPTIME sec"
		${PROPCLI} set System.QA.WorkingCounterSec $STORED_UPTIME
	fi

	if [ -f $UPTIME_FILE ]; then
		UPTIME=$(cat $UPTIME_FILE)
		TMP=$((UPTIME+STORED_UPTIME-LAST_SYNCH))
		log_info "Uptime from file: $UPTIME, stored working counter: $STORED_UPTIME, last synch: $LAST_SYNCH"
		log_info "New value of working counter: $TMP"

		${PROPCLI} set System.QA.WorkingCounterSec $TMP
		rm -f $UPTIME_FILE
	fi

	echo 0 > $SYNCH_FILE
    sync
}

do_onSoftReset()
{
    wait_ipc 2
    TMP=`${PROPCLI} get System.QA.SoftReboots`
    TMP=$((TMP+1))
    ${PROPCLI} set System.QA.SoftReboots $TMP
    sync
}

case "$1" in
 start)
	do_onStart
	;;
 stop)
	do_onSoftReset
	;;
 *)
	echo "Usage: $0 [ start | stop ] " >&2
	exit 1
	;;
esac

exit 0
